![Build Status](https://github.com/hotdoc/hotdoc/workflows/python/badge.svg)

![Hotdoc logo](https://cdn.rawgit.com/hotdoc/hotdoc/master/documentation/hotdoc.svg)

This project needs a logo. In the meantime, eyes will get hurt by this 
horrible illustration of programmer art.

Hotdoc is a documentation micro-framework. It provides an interface for
extensions to plug upon, along with some base objects (formatters, ...)

Please check the packages listed at [https://github.com/hotdoc](https://github.com/hotdoc) to
pick the extensions you are interested in.

You can find the documentation for hotdoc, by hotdoc [here](https://hotdoc.github.io/)

### Licensing

hotdoc is licensed under the LGPL version 2.1 (or, at your option, any
later version). See COPYING for more details.
